@@ -9,6 +9,8 @@ import re
 import time
 import struct
 import datetime
+from decimal import Decimal
+from uuid import UUID
 
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.functional import cached_property
@@ -124,7 +126,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         'SmallIntegerField': 'smallint',
         'TextField': 'nvarchar(max)',
         'TimeField': 'time',
-        'UUIDField': 'char(32)',
+        'UUIDField': 'uniqueidentifier',
     }
     data_types_suffix = {
         'AutoField': 'IDENTITY (1, 1)',
@@ -376,7 +378,6 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                         break
                 if not need_to_retry:
                     raise
-
         # Handling values from DATETIMEOFFSET columns
         # source: https://github.com/mkleehammer/pyodbc/wiki/Using-an-Output-Converter-function
         conn.add_output_converter(SQL_TIMESTAMP_WITH_TIMEZONE, handle_datetimeoffset)
@@ -431,6 +432,9 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         if (options.get('return_rows_bulk_insert', False)):
             self.features_class.can_return_rows_from_bulk_insert = True
 
+        if (options.get('has_native_uuid_field', True)):
+            Database.native_uuid = True
+            
         val = self.get_system_datetime
         if isinstance(val, str):
             raise ImproperlyConfigured(
@@ -569,6 +573,36 @@ class CursorWrapper(object):
         self.last_sql = ''
         self.last_params = ()
 
+    def _as_sql_type(self, typ, value):
+        if isinstance(value, str):
+            length = len(value)
+            if length == 0:
+                return 'NVARCHAR'
+            elif length > 4000:
+                return 'NVARCHAR(max)'
+            return 'NVARCHAR(%s)' % len(value)
+        elif typ == int:
+            if value < 0x7FFFFFFF and value > -0x7FFFFFFF:
+                return 'INT'
+            else:
+                return 'BIGINT'
+        elif typ == float:
+            return 'DOUBLE PRECISION'
+        elif typ == bool:
+            return 'BIT'
+        elif isinstance(value, Decimal):
+            return 'NUMERIC'
+        elif isinstance(value, datetime.datetime):
+            return 'DATETIME2'
+        elif isinstance(value, datetime.date):
+            return 'DATE'
+        elif isinstance(value, datetime.time):
+            return 'TIME'
+        elif isinstance(value, UUID):
+            return 'uniqueidentifier'
+        else:
+            raise NotImplementedError('Not supported type %s (%s)' % (type(value), repr(value)))
+
     def close(self):
         if self.active:
             self.active = False
@@ -586,6 +620,27 @@ class CursorWrapper(object):
 
         return sql
 
+    def format_group_by_params(self, query, params):
+        if params:
+            # Insert None params directly into the query
+            if None in params:
+                null_params = ['NULL' if param is None else '%s' for param in params]
+                query = query % tuple(null_params)
+                params = tuple(p for p in params if p is not None)
+            params = [(param, type(param)) for param in params]
+            params_dict = {param: '@var%d' % i for i, param in enumerate(set(params))}
+            args = [params_dict[param] for param in params]
+
+            variables = []
+            params = []
+            for key, value in params_dict.items():
+                datatype = self._as_sql_type(key[1], key[0])
+                variables.append("%s %s = %%s " % (value, datatype))
+                params.append(key[0])
+            query = ('DECLARE %s \n' % ','.join(variables)) + (query % tuple(args))
+
+        return query, params
+
     def format_params(self, params):
         fp = []
         if params is not None:
@@ -614,6 +669,8 @@ class CursorWrapper(object):
 
     def execute(self, sql, params=None):
         self.last_sql = sql
+        if 'GROUP BY' in sql:
+            sql, params = self.format_group_by_params(sql, params)
         sql = self.format_sql(sql, params)
         params = self.format_params(params)
         self.last_params = params
